@@ -10,8 +10,7 @@ This contains the necessary definitions to make the main_window fixture
 available for integration tests.
 """
 
-# Standard library imports
-import os
+import time
 
 # Third-party imports
 from qtpy.QtWidgets import QApplication
@@ -25,6 +24,7 @@ from qtpy import QtWebEngineWidgets  # noqa
 from spyder import version_info as spyder_version_info
 from spyder.api.plugin_registration.registry import PLUGIN_REGISTRY
 from spyder.app import start
+from spyder.config.base import running_in_ci
 from spyder.config.manager import CONF
 
 
@@ -34,12 +34,6 @@ def main_window(monkeypatch):
 
     # Don't show tours message
     CONF.set('tours', 'show_tour_message', False)
-
-    # Turn introspection on, even though it's slower and more memory
-    # intensive, because otherwise tests are aborted at end with
-    # "QThread: Destroyed while thread is still running".
-    os.environ['SPY_TEST_USE_INTROSPECTION'] = 'True'
-
     QApplication.processEvents()
 
     # Start the window
@@ -48,11 +42,14 @@ def main_window(monkeypatch):
 
     yield window
 
+    # This is to prevent "QThread: Thread still running" error
+    if running_in_ci():
+        time.sleep(5)
+        QApplication.processEvents()
+
     # Close main window
     window.closing(close_immediately=True)
     window.close()
     CONF.reset_to_defaults(notification=False)
     CONF.reset_manager()
     PLUGIN_REGISTRY.reset()
-
-    os.environ.pop('SPY_TEST_USE_INTROSPECTION')
