@@ -24,8 +24,9 @@ class UnitTestConfigPage(PluginConfigPage):
 
     def setup_page(self) -> None:
         settings_group = QGroupBox(_('Settings'))
-        self.abbrev_box = self.create_checkbox(
+        widget = self.create_checkbox(
             _('Abbreviate test names'), 'abbrev_test_names', default=False)
+        self.abbrev_box = widget.checkbox
 
         settings_layout = QVBoxLayout()
         settings_layout.addWidget(self.abbrev_box)
