@@ -8,7 +8,7 @@
 # Standard library imports
 import os
 import sys
-from unittest.mock import Mock
+from unittest.mock import Mock, patch
 
 # Third party imports
 from qtpy.QtCore import Qt, QProcess
@@ -151,15 +151,22 @@ def test_unittestwidget_process_finished_abnormally_status_label(widget):
     expected_text = '<b>{}</b>'.format('Test process exited abnormally')
     assert widget.status_label.text() == expected_text
 
-@pytest.mark.parametrize('framework', ['pytest', 'nose'])
-def test_run_tests_and_display_results(qtbot, widget, tmpdir, monkeypatch, framework):
+def test_unittestwidget_handles_sig_single_test_run_requested(widget):
+    with patch.object(widget, 'run_tests') as mock_run_tests:
+        widget.testdataview.sig_single_test_run_requested.emit('testname')
+        mock_run_tests.assert_called_once_with(single_test='testname')
+
+@pytest.mark.parametrize('framework', ['pytest', 'nose2'])
+@pytest.mark.parametrize('alltests', [True, False])
+def test_run_tests_and_display_results(qtbot, widget, tmpdir, monkeypatch,
+                                       framework, alltests):
     """Basic integration test."""
     os.chdir(tmpdir.strpath)
     testfilename = tmpdir.join('test_foo.py').strpath
 
     with open(testfilename, 'w') as f:
-        f.write("def test_ok(): assert 1+1 == 2\n"
-                "def test_fail(): assert 1+1 == 3\n")
+        f.write("def test_fail(): assert 1+1 == 3\n"
+                "def test_ok(): assert 1+1 == 2\n")
 
     MockQMessageBox = Mock()
     monkeypatch.setattr('spyder_unittest.widgets.unittestgui.QMessageBox',
@@ -167,24 +174,29 @@ def test_run_tests_and_display_results(qtbot, widget, tmpdir, monkeypatch, frame
 
     config = Config(wdir=tmpdir.strpath, framework=framework, coverage=False)
     with qtbot.waitSignal(widget.sig_finished, timeout=10000, raising=True):
-        widget.run_tests(config)
+        if alltests:
+            widget.run_tests(config)
+        else:
+            widget.run_tests(config, single_test='test_foo.test_fail')
 
     MockQMessageBox.assert_not_called()
     model = widget.testdatamodel
-    assert model.rowCount() == 2
+    assert model.rowCount() == (2 if alltests else 1)
     assert model.index(0, 0).data(
-        Qt.DisplayRole) == 'ok' if framework == 'nose' else 'passed'
-    assert model.index(0, 1).data(Qt.DisplayRole) == 't.test_ok'
-    assert model.index(0, 1).data(Qt.ToolTipRole) == 'test_foo.test_ok'
-    assert model.index(0, 2).data(Qt.DisplayRole) == ''
-    assert model.index(1, 0).data(
-        Qt.DisplayRole) == 'failure' if framework == 'nose' else 'failed'
-    assert model.index(1, 1).data(Qt.DisplayRole) == 't.test_fail'
-    assert model.index(1, 1).data(Qt.ToolTipRole) == 'test_foo.test_fail'
+        Qt.DisplayRole) == 'failure' if framework == 'nose2' else 'failed'
+    assert model.index(0, 1).data(Qt.DisplayRole) == 'test_foo.test_fail'
+    assert model.index(0, 1).data(Qt.ToolTipRole) == 'test_foo.test_fail'
+    if alltests:
+        assert model.index(1, 0).data(
+            Qt.DisplayRole) == 'ok' if framework == 'nose2' else 'passed'
+        assert model.index(1, 1).data(Qt.DisplayRole) == 'test_foo.test_ok'
+        assert model.index(1, 1).data(Qt.ToolTipRole) == 'test_foo.test_ok'
+        assert model.index(1, 2).data(Qt.DisplayRole) == ''
 
 
+@pytest.mark.parametrize('alltests', [True, False])
 def test_run_tests_using_unittest_and_display_results(
-        qtbot, widget, tmpdir, monkeypatch):
+        qtbot, widget, tmpdir, monkeypatch, alltests):
     """Basic check."""
     os.chdir(tmpdir.strpath)
     testfilename = tmpdir.join('test_foo.py').strpath
@@ -199,6 +211,48 @@ def test_run_tests_using_unittest_and_display_results(
     monkeypatch.setattr('spyder_unittest.widgets.unittestgui.QMessageBox',
                         MockQMessageBox)
 
+    config = Config(wdir=tmpdir.strpath, framework='unittest', coverage=False)
+    with qtbot.waitSignal(widget.sig_finished, timeout=10000, raising=True):
+        if alltests:
+            widget.run_tests(config)
+        else:
+            widget.run_tests(config, single_test='test_foo.MyTest.test_fail')
+
+    MockQMessageBox.assert_not_called()
+    model = widget.testdatamodel
+    assert model.rowCount() == (2 if alltests else 1)
+    assert model.index(0, 0).data(Qt.DisplayRole) == 'failure'
+    assert model.index(0, 1).data(Qt.DisplayRole) == 'test_foo.MyTest.test_fail'
+    assert model.index(0, 1).data(Qt.ToolTipRole) == 'test_foo.MyTest.test_fail'
+    if alltests:
+        assert model.index(1, 0).data(Qt.DisplayRole) == 'success'
+        assert model.index(1, 1).data(Qt.DisplayRole) == 'test_foo.MyTest.test_ok'
+        assert model.index(1, 1).data(Qt.ToolTipRole) == 'test_foo.MyTest.test_ok'
+        assert model.index(1, 2).data(Qt.DisplayRole) == ''
+
+def test_run_tests_with_print_using_unittest_and_display_results(
+        qtbot, widget, tmpdir, monkeypatch):
+    """
+    Run a failing test which print to stderr using unittest and check
+    that it is displayed as a failing test.
+    Regression test for spyder-ide/spyder-unittest#160.
+    """
+    os.chdir(tmpdir.strpath)
+    testfilename = tmpdir.join('test_foo.py').strpath
+
+    with open(testfilename, 'w') as f:
+        f.write("import sys\n"
+                "import unittest\n"
+                "class MyTest(unittest.TestCase):\n"
+                "    def test_fail(self):\n"
+                "        print('text', file=sys.stderr)\n"
+                "        self.assertEqual(1+1, 3)\n"
+                "    def test_ok(self): self.assertEqual(1+1, 2)\n")
+
+    MockQMessageBox = Mock()
+    monkeypatch.setattr('spyder_unittest.widgets.unittestgui.QMessageBox',
+                        MockQMessageBox)
+
     config = Config(wdir=tmpdir.strpath, framework='unittest', coverage=False)
     with qtbot.waitSignal(widget.sig_finished, timeout=10000, raising=True):
         widget.run_tests(config)
@@ -206,16 +260,10 @@ def test_run_tests_using_unittest_and_display_results(
     MockQMessageBox.assert_not_called()
     model = widget.testdatamodel
     assert model.rowCount() == 2
-    assert model.index(0, 0).data(Qt.DisplayRole) == 'FAIL'
-    assert model.index(0, 1).data(Qt.DisplayRole) == 't.M.test_fail'
-    assert model.index(0, 1).data(Qt.ToolTipRole) == 'test_foo.MyTest.test_fail'
-    assert model.index(0, 2).data(Qt.DisplayRole) == ''
-    assert model.index(1, 0).data(Qt.DisplayRole) == 'ok'
-    assert model.index(1, 1).data(Qt.DisplayRole) == 't.M.test_ok'
-    assert model.index(1, 1).data(Qt.ToolTipRole) == 'test_foo.MyTest.test_ok'
-    assert model.index(1, 2).data(Qt.DisplayRole) == ''
+    assert model.index(0, 0).data(Qt.DisplayRole) == 'failure'
+    assert model.index(1, 0).data(Qt.DisplayRole) == 'success'
 
-@pytest.mark.parametrize('framework', ['unittest', 'pytest', 'nose'])
+@pytest.mark.parametrize('framework', ['unittest', 'pytest', 'nose2'])
 def test_run_with_no_tests_discovered_and_display_results(
         qtbot, widget, tmpdir, monkeypatch, framework):
     """Basic integration test."""
